####### Librarying packages and selecting directory #####
library(devtools)
library(treeman)
library(ape)
library(picante)
library(phangorn)
library(seqinr)
library(ips)
library(ips)
library(MCMCtreeR)
library(treeio)
library("seqinr")
library(phytools)
library(data.table)
library(vegan)
library(ggplot2)
library(brms)
library(tidytree)
library(hillR)
library(mgcv)
library(gratia)
library(tidyverse)

##### data manipulation #####

# joining host occurrence,  environmental data and functional traits data (PCA) to geographical data

load("GAM_Files.RData") # files created for de Angeli Dutra et al 2023 Ecography

dataGamm1 <- dados[,c(1,2,40:43,7,13,12,21,27,32,35)]

bird_rich <- distinct(dplyr::select(birdocc7, sitecolumn, species))
bird_rich1 = bird_rich %>%
  group_by(sitecolumn) %>%
  dplyr::summarise(bird_rich = n_distinct(species),
                   abundance = n())

dataGamm1 <- inner_join(dataGamm1, bird_rich1, by= "sitecolumn")

###### Calculate Bird Phylogenetic Diversity ######

##### Bird Phylogeny #####
allTrees <- readTree("AllBirdsHackett1.tre")
random_trees <-sample(allTrees@treelst, size = 100)
random_trees1 <- as(random_trees, 'TreeMen')
random_trees2 <- as(random_trees1, 'multiPhylo')

#load("random_trees2.RData")

# Function to get a random tree from a multiphylo object
getRandomTree <- function(multiphylo_object) {
  # Get the number of trees in the multiphylo object
  num_trees <- length(multiphylo_object)
  
  # Generate a random index to select a tree
  random_index <- sample(1:num_trees, 1)
  
  # Extract the random tree
  random_tree <- multiphylo_object[[random_index]]
  
  return(random_tree)
}

mytree <- getRandomTree(random_trees2)
bird_rich$species <- gsub(" ", "_", bird_rich$species)

matchesBirds <-match(bird_rich$species, mytree$tip.label)
matchesBirds <-na.omit(matchesBirds)
mytree1 <-drop.tip(mytree, mytree$tip.label[-matchesBirds])

length(unique(mytree1$tip.label))
length(unique(bird_rich$species))

Int_mat <- fossil::create.matrix(bird_rich, tax.name ="species", locality ="sitecolumn", abund = FALSE)
Int_mat <- t(Int_mat)

Phy_Hill <- hill_phylo(Int_mat, mytree1)
Phy_Hill <- as.data.frame(Phy_Hill)

Phy_Hill1 <- Phy_Hill[rownames(Phy_Hill),]
Phy_Hill1 <- as.data.frame(Phy_Hill1)

Phy_Hill1 <- rownames_to_column(Phy_Hill, var = "sitecolumn") %>% as_tibble()

dataGamm1 <- inner_join(dataGamm1, Phy_Hill1, by = "sitecolumn")

###### Checking for collinearity ######

library(GGally) #for ggpairs

Mydotplot <- function(DataSelected){
  
  P <- dotplot(as.matrix(as.matrix(DataSelected)),
               groups=FALSE,
               strip = strip.custom(bg = 'white',
                                    par.strip.text = list(cex = 1.2)),
               scales = list(x = list(relation = "free", draw = TRUE),
                             y = list(relation = "free", draw = FALSE)),
               col=1, cex  = 0.5, pch = 16,
               xlab = list(label = "Value of the variable", cex = 1.5),
               ylab = list(label = "Order of the data", cex = 1.5))
  
  print(P)  
}

MyVar <- as.vector(colnames(Combdata[,c(16,22,27,30)]))
#MyVar <- c("VariableName1", "VariableName2", "VariableName3")
Mydotplot(Combdata[,MyVar])
ggpairs(Combdata[,MyVar])

MyVar2 <- as.vector(colnames(Combdata[, c(4:12)]))
Mydotplot(Combdata[,MyVar2])
ggpairs(Combdata[,MyVar2])
cor2 <-  as.data.frame(cor(Combdata[, c(4:12)]))

# Count the number of times values are above the threshold
cor2$above_count <- apply(cor2, 1, function(row) sum(row > 0.8))

# Count the number of times values are below the threshold
cor2$below_count <- apply(cor2, 1, function(row) sum(row < -0.8))

# total
cor2$total <- cor2$above_count + cor2$below_count

# Use migratory status and body size in the model

##### Calculating regional biodiversity ######

# creating occurrence matrix
dataGamm1$Lineage_Fasta[dataGamm1$parasiteGenus == "Plasmodium"] <- "P_"
dataGamm1$Lineage_Fasta[dataGamm1$parasiteGenus == "Haemoproteus"] <- "H_"
dataGamm1$Lineage_Fasta[dataGamm1$parasiteGenus == "Leucocytozoon"] <- "L_"

dataGamm1$Lineage_Fasta <- paste(dataGamm1$Lineage_Fasta, dataGamm1$Lineage_Name, sep = "")
dataGamm1 <- distinct(dataGamm1)

occdata <- dataGamm1[,c(3,17)]

occdata <- as.data.table(occdata)
occmatrix <- dcast.data.table(occdata, sitecolumn ~ Lineage_Fasta)
occmatrix <- tibble::column_to_rownames(occmatrix, var = "sitecolumn")

##### Creating Fasta File for Parasite Phylogeny #####
dados1 <- dataGamm1[,c(1,2,17)]
dados1 <- distinct(dados1)

# Creating fasta
fasta <- read.FASTA("Malavi_Long.fasta", type = "DNA")
class(fasta)
print(fasta)

fasta1 <- fasta[names(fasta) %in% dados1$Lineage_Fasta]

write.FASTA(fasta1, "HaemSeq.fasta")

write.dna(fasta1, "HaemSeq.NEX", format = "sequential", append = FALSE,
          nbcol = 3, colsep = "", colw = 500, indent = NULL,
          blocksep = 1)

##### loading parasite phylogeny ######
library(ips)
phylo_tree <- read.mrbayes("Div_phy.tre")
class(phylo_tree)
phylo <- phylo_tree@phylo
class(phylo)
is.rooted(phylo)

##### Calculating phylogenetic diversity ######
matches <-match(dataGamm1$Lineage_Fasta, phylo$tip.label)
matches <-na.omit(matches)

occdata <- as.data.table(occdata)
occmatrix <- dcast.data.table(occdata, sitecolumn ~ Lineage_Fasta)
occmatrix <- tibble::column_to_rownames(occmatrix, var = "sitecolumn")

phylo <-drop.tip(phylo, phylo$tip.label[-matches])

phylo_div <- picante::pd(occmatrix, phylo, include.root = FALSE) 
phylo_div <- rownames_to_column(phylo_div)

# Plasmodium 
dataGamm1P <- filter(dataGamm1, parasiteGenus == "Plasmodium")
matchesP <-match(dataGamm1P$Lineage_Fasta, phylo$tip.label)
matchesP <-na.omit(matches)
phyloP <-drop.tip(phylo, phylo$tip.label[-matchesP])

MatrixP <- fossil::create.matrix(dataGamm1P, tax.name ="Lineage_Fasta", locality ="sitecolumn", abund = FALSE)
MatrixP <- t(MatrixP)

phylo_divP <- picante::pd(MatrixP, phyloP, include.root = FALSE) 
phylo_divP <- rownames_to_column(phylo_divP)
phylo_divP <- na.omit(phylo_divP)

# Haemoproteus
dataGamm1H <- filter(dataGamm1, parasiteGenus == "Haemoproteus")
matchesH <-match(dataGamm1H$Lineage_Fasta, phylo$tip.label)
matchesH <-na.omit(matches)
phyloH <-drop.tip(phylo, phylo$tip.label[-matchesH])

MatrixH <- fossil::create.matrix(dataGamm1H, tax.name ="Lineage_Fasta", locality ="sitecolumn", abund = FALSE)
MatrixH <- t(MatrixH)

phylo_divH <- picante::pd(MatrixH, phyloH, include.root = FALSE) 
phylo_divH <- rownames_to_column(phylo_divH)
phylo_divH <- na.omit(phylo_divH)

# Leucocytozoon 
dataGamm1L <- filter(dataGamm1, parasiteGenus == "Leucocytozoon")
matchesL <-match(dataGamm1L$Lineage_Fasta, phylo$tip.label)
matchesL <-na.omit(matches)
phyloL <-drop.tip(phylo, phylo$tip.label[-matchesL])

MatrixL <- fossil::create.matrix(dataGamm1L, tax.name ="Lineage_Fasta", locality ="sitecolumn", abund = FALSE)
MatrixL <- t(MatrixL)

phylo_divL <- picante::pd(MatrixL, phyloL, include.root = FALSE) 
phylo_divL <- rownames_to_column(phylo_divL)
phylo_divL <- na.omit(phylo_divL)

###### Organizing variables ######
dataGamm1 <- inner_join(dataGamm1, phylo_div, by = c("sitecolumn" = "rowname"))
dataGamm1 <- left_join(dataGamm1, dplyr::select(phylo_divP, rowname, PD), by = c("sitecolumn" = "rowname"))
dataGamm1 <- left_join(dataGamm1, dplyr::select(phylo_divH, rowname, PD), by = c("sitecolumn" = "rowname"))
dataGamm1 <- left_join(dataGamm1, dplyr::select(phylo_divL, rowname, PD), by = c("sitecolumn" = "rowname"))

###### calculating sampling effort ######
dataGamm2 = dataGamm1%>%
  group_by(sitecolumn, .add = TRUE)%>%
  dplyr::summarise(par_richness = n_distinct(Lineage_Name),
                   sampling = n())%>%
  arrange(sitecolumn)

data <- inner_join(dataGamm1, dataGamm2, by = "sitecolumn")

# checking for spatial correlation
dataGamm3 <- inner_join(dataGamm2, dplyr::select(dados, sitecolumn, Latitude, Longitude), by = "sitecolumn")
dataGamm3 <- distinct(dataGamm3)
dataGamm3 <- inner_join(dataGamm3, phylo_div, by = c("sitecolumn" = "rowname"))

matrix <- as.matrix(dist(cbind(dataGamm3$Longitude, dataGamm3$Latitude)))
matrix1 <- 1/matrix
diag(matrix1) <- 0
matrix1 <-ifelse(matrix1=="Inf",0,matrix1 )

matrix1[1:5, 1:5]

library(ape)
Moran.I(dataGamm3$PD, matrix1, na.rm = TRUE, scaled = TRUE) # high correlation = 0.56

##### preparing variables #####
data_scale <- data
data_scale <- separate(data_scale, col = LatLong, sep = "_", into = c("Lat", "Long"))

# calculating percentage of resident hosts in each grid
data_scale$residents <- gsub("resident", 1, data$distance_4)
data_scale$Body_mass<- as.numeric(data_scale$Body_mass)

residents <- data_scale %>%
  group_by(sitecolumn) %>%
  summarise(residents = sum(residents == 1),
            Body_mass = mean(Body_mass),
            n = n()) %>%
  mutate(pro.residents =residents/n,
         pro.migrants = (pro.residents-1)*-1)

# scaling variables
data_scale <- data_scale[,c(2:5,11:17, 19:25)]
data_scale <- inner_join(data_scale, residents[,c(1,3,5:6)], by = "sitecolumn")
data_scale <- distinct(data_scale)

##### Checking variables class and distribution ######
sapply(data_scale[,c(5:21)], class)
data_scale[,c(3:21)] <- sapply(data_scale[,c(3:21)], as.numeric)
data_scale[,c(5:21)] <- base::scale(data_scale[,c(5:21)])

hist(data_scale$Body_mass)
hist(data_scale$bio1)
hist(data_scale$bio7)
hist(data_scale$bio12)
hist(data_scale$bio15)
hist(data_scale$bird_rich)
hist(data_scale$sampling)
hist(data_scale$PD.x)

dataP <- filter(data_scale, parasiteGenus == "Plasmodium")
dataH <- filter(data_scale, parasiteGenus == "Haemoproteus")
dataL <- filter(data_scale, parasiteGenus == "Leucocytozoon")

data_scale$parasiteGenus <- NULL

# removing NAs
colSums(is.na(data_scale))

dataP <- dataP[,-c(15,16)]
dataP <- na.omit(dataP)

dataH <- dataH[,-c(14,16)]
dataH <- na.omit(dataH)

dataL <- dataL[,-c(14,15)]
dataL <- na.omit(dataL)

data_scale <- distinct(data_scale)
dataP <- distinct(dataP)
dataH <- distinct(dataH)
dataL <- distinct(dataL)

#### GLS models ####
GLS <- nlme::gls(PD.x ~  pro.migrants + Body_mass + bio1 + bio7 + bio12 + bio15 + Phy_Hill + sampling, 
                 data = data_scale, correlation = corExp(form = ~ Long + Lat))

parameters::parameters(GLS)
plot(GLS)

# Plasmodium
GLS_P <- nlme::gls(PD.y ~ pro.migrants + Body_mass + bio1 + bio7 + bio12 + bio15 + Phy_Hill + sampling, 
                   data = dataP, correlation = corExp(form = ~ Long + Lat))

parameters::parameters(GLS_P)
plot(GLS_P)

# Haemoproteus
GLS_H <- nlme::gls(PD.x.x ~ pro.migrants + Body_mass + bio1 + bio7 + bio12 + bio15 + Phy_Hill + sampling, 
                   data = dataH, correlation = corExp(form = ~ Long + Lat))

parameters::parameters(GLS_H)
plot(GLS_H)

# Leucocytozoon
GLS_L <- nlme::gls(PD.y.y ~ pro.migrants + Body_mass + bio1 + bio7 + bio12 + bio15 + Phy_Hill + sampling, 
                   data = dataL, correlation = corExp(form = ~ Long + Lat))

parameters::parameters(GLS_L)
plot(GLS_L)

save.image("analyses_Phy_Spatio.RData")


##### PLOTS ######
load("analyses_Phy_Spatio.RData")

data_scale$predicted <- predict(GLS, newdata = data_scale)
dataP$predicted <- predict(GLS_P, newdata = dataP)
dataL$predicted <- predict(GLS_L, newdata = dataL)

# Make predictions using the model

p1 <- ggplot(data = dataP, aes(Phy_Hill, predicted)) + labs(x = "Host phylogenetic diversity", y = "Haemosporidian phylogenetic diversity", title = "A") +
  geom_point(colour = 'darkgreen', size = 1.6) +
  geom_smooth(method = "glm", aes(y =predicted), colour = "darkgreen")
p1 <- p1 + theme_classic()

p2 <- ggplot(data = data_scale, aes(Body_mass, predicted)) + labs(x = "Host body mass", y = "Haemosporidian phylogenetic diversity", title = "B") +
  geom_point(colour = "purple", size = 1.6) +
  geom_smooth(method = "glm", aes(y = predicted), colour = "purple") + ylim(-1, 1)
p2 <- p2 + theme_classic()

p3 <- ggplot(data = dataL, aes(pro.migrants, predicted)) + labs(x = "Proportion of migrant hosts", y = "Leucocytozoon phylogenetic diversity", title = "C") +
  geom_point(data = dataL, aes(y = predicted), colour = 'red', size = 1.6) +
  geom_smooth(method = "glm", aes(y = predicted), colour = "red")  + ylim(-1, 0.7)
p3 <- p3 + theme_classic()

p4 <- ggplot(data = data_scale, aes(sampling, predicted)) + labs(x = "Sampling Effort", y = "Haemosporidian phylogenetic diversity", title = "D") +
  geom_point(colour = 'blue', size = 1.6) +
  geom_smooth(method = "glm", aes(y = predicted), colour = "blue")
p4 <- p4 + theme_classic()


library(patchwork)

p1 + p2 + p3 + p4 + 
  plot_layout(ncol = 4, nrow = 1)

ggsave(filename = "Figure 2.pdf", dpi = 600, width = 10, height = 6)


# checking residuals 
plot(residuals(GLS))
plot(residuals(GLS_P))
plot(residuals(GLS_H))
plot(residuals(GLS_L))

# Extract residuals
residuals <- resid(GLS)

# Create a data frame for plotting
plot_data <- data.frame(
  FittedValues = fitted(GLS),
  Residuals = residuals
)

# Plot residuals against fitted values (repeat for each model)
r1 <- ggplot(plot_data, aes(x = FittedValues, y = Residuals)) +
  geom_point(color = "blue", size = 3, alpha = 0.7) +
  geom_hline(yintercept = 0, linetype = "dashed", color = "red") + theme_classic() +
  labs(
    title = "Residuals Plot for model evaluating haemosporidian diversity",
    x = "Fitted Values",
    y = "Residuals"
  )


r1 + r2 + r3 + r4 + 
  plot_layout(ncol = 2, nrow = 2)

ggsave(filename = "supplementary Figure 3.pdf", dpi = 600, width = 12, height = 7)

save.image("GLS.Rdata")

# Map
library(raster)
points <- SpatialPoints(Combdata[,c(14,15)])
birdrast_map <- raster("C:/Users/danid/OneDrive - Stanford/Otago/Lab Poulin/PhD/PhD/Dados/Capítulo 5 e 6/Tabelas e arquivos R/birdrichness.gri")
png("Figure 1.png", width = 9, height = 6, units = "in", res = 600)
raster::plot(birdrast_map,xlab = "Longitude", ylab = "Latitude")
plot(points, add = T, pch = 21, bg = "purple", col = "navy", cex = 0.7)
dev.off()

# Load libraries
library(maps)
library(mapdata)
library(ggplot2)

# Load libraries for raster data handling
library(raster)
library(sf)
library(RColorBrewer)

# Plot the raster with the 'Blues' color palette
raster::plot(birdrast_map, col = brewer.pal(5, "Greens"),main = "Global avian diversity")

